@@ -118,8 +118,9 @@ class OAuth2FlowResult(OAuth2FlowNoRedirectResult):
 
 class DropboxOAuth2FlowBase(object):
 
-    def __init__(self, consumer_key, consumer_secret=None, locale=None, token_access_type='legacy',
-                 scope=None, include_granted_scopes=None, use_pkce=False, timeout=DEFAULT_TIMEOUT):
+    def __init__(self, consumer_key, consumer_secret=None, locale=None, token_access_type=None,
+                 scope=None, include_granted_scopes=None, use_pkce=False, timeout=DEFAULT_TIMEOUT,
+                 ca_certs=None):
         if scope is not None and (len(scope) == 0 or not isinstance(scope, list)):
             raise BadInputException("Scope list must be of type list")
         if token_access_type is not None and token_access_type not in TOKEN_ACCESS_TYPES:
@@ -134,7 +135,7 @@ class DropboxOAuth2FlowBase(object):
         self.consumer_secret = consumer_secret
         self.locale = locale
         self.token_access_type = token_access_type
-        self.requests_session = pinned_session()
+        self.requests_session = pinned_session(ca_certs=ca_certs)
         self.scope = scope
         self.include_granted_scopes = include_granted_scopes
         self._timeout = timeout
@@ -146,7 +147,7 @@ class DropboxOAuth2FlowBase(object):
             self.code_verifier = None
             self.code_challenge = None
 
-    def _get_authorize_url(self, redirect_uri, state, token_access_type, scope=None,
+    def _get_authorize_url(self, redirect_uri, state, token_access_type=None, scope=None,
                            include_granted_scopes=None, code_challenge=None):
         params = dict(response_type='code',
                       client_id=self.consumer_key)
@@ -156,8 +157,7 @@ class DropboxOAuth2FlowBase(object):
             params['state'] = state
         if token_access_type is not None:
             assert token_access_type in TOKEN_ACCESS_TYPES
-            if token_access_type != 'legacy':
-                params['token_access_type'] = token_access_type
+            params['token_access_type'] = token_access_type
         if code_challenge:
             params['code_challenge'] = code_challenge
             params['code_challenge_method'] = 'S256'
@@ -268,13 +268,14 @@ class DropboxOAuth2FlowNoRedirect(DropboxOAuth2FlowBase):
     OAuth 2 authorization helper for apps that can't provide a redirect URI
     (such as the command-line example apps).
 
-    See examples under `example/oauth <https://github.com/dropbox/dropbox-sdk-python/tree/master/
+    See examples under `example/oauth <https://github.com/dropbox/dropbox-sdk-python/tree/main/
     example/oauth>`_
 
     """
 
-    def __init__(self, consumer_key, consumer_secret=None, locale=None, token_access_type='legacy',
-                 scope=None, include_granted_scopes=None, use_pkce=False, timeout=DEFAULT_TIMEOUT):  # noqa: E501;
+    def __init__(self, consumer_key, consumer_secret=None, locale=None, token_access_type=None,
+                 scope=None, include_granted_scopes=None, use_pkce=False, timeout=DEFAULT_TIMEOUT,
+                 ca_certs=None):  # noqa: E501;
         """
         Construct an instance.
 
@@ -286,6 +287,7 @@ class DropboxOAuth2FlowNoRedirect(DropboxOAuth2FlowBase):
         :param str token_access_type: the type of token to be requested.
             From the following enum:
 
+            * None - creates a token with the app default (either legacy or online)
             * legacy - creates one long-lived token with no expiration
             * online - create one short-lived token with an expiration
             * offline - create one short-lived token with an expiration with a refresh token
@@ -306,6 +308,8 @@ class DropboxOAuth2FlowNoRedirect(DropboxOAuth2FlowBase):
             client will wait for any single packet from the server. After the timeout the client
             will give up on connection. If `None`, client will wait forever. Defaults
             to 100 seconds.
+        :param str ca_cert: path to CA certificate. If left blank, default certificate location \
+            will be used
         """
         super(DropboxOAuth2FlowNoRedirect, self).__init__(
             consumer_key=consumer_key,
@@ -315,7 +319,8 @@ class DropboxOAuth2FlowNoRedirect(DropboxOAuth2FlowBase):
             scope=scope,
             include_granted_scopes=include_granted_scopes,
             use_pkce=use_pkce,
-            timeout=timeout
+            timeout=timeout,
+            ca_certs=ca_certs
         )
 
     def start(self):
@@ -352,20 +357,20 @@ class DropboxOAuth2Flow(DropboxOAuth2FlowBase):
     OAuth 2 has a two-step authorization process. The first step is having the user authorize your
     app. The second involves getting an OAuth 2 access token from Dropbox.
 
-    See examples under `example/oauth <https://github.com/dropbox/dropbox-sdk-python/tree/master/
+    See examples under `example/oauth <https://github.com/dropbox/dropbox-sdk-python/tree/main/
     example/oauth>`_
 
     """
 
     def __init__(self, consumer_key, redirect_uri, session,
                  csrf_token_session_key, consumer_secret=None, locale=None,
-                 token_access_type='legacy', scope=None,
-                 include_granted_scopes=None, use_pkce=False, timeout=DEFAULT_TIMEOUT):
+                 token_access_type=None, scope=None,
+                 include_granted_scopes=None, use_pkce=False, timeout=DEFAULT_TIMEOUT,
+                 ca_certs=None):
         """
         Construct an instance.
 
         :param str consumer_key: Your API app's "app key".
-        :param str consumer_secret: Your API app's "app secret".
         :param str redirect_uri: The URI that the Dropbox server will redirect the user to after the
             user finishes authorizing your app.  This URI must be HTTPS-based and pre-registered
             with the Dropbox servers, though localhost URIs are allowed without pre-registration and
@@ -374,12 +379,14 @@ class DropboxOAuth2Flow(DropboxOAuth2FlowBase):
             (Will be used to save the CSRF token).
         :param str csrf_token_session_key: The key to use when storing the CSRF token in the session
             (For example: "dropbox-auth-csrf-token").
+        :param str consumer_secret: Your API app's "app secret".
         :param str locale: The locale of the user of your application. For example "en" or "en_US".
             Some API calls return localized data and error messages; this setting tells the server
             which locale to use. By default, the server uses "en_US".
         :param str token_access_type: The type of token to be requested.
             From the following enum:
 
+            * None - creates a token with the app default (either legacy or online)
             * legacy - creates one long-lived token with no expiration
             * online - create one short-lived token with an expiration
             * offline - create one short-lived token with an expiration with a refresh token
@@ -398,6 +405,8 @@ class DropboxOAuth2Flow(DropboxOAuth2FlowBase):
         :param Optional[float] timeout: Maximum duration in seconds that client will wait for any
             single packet from the server. After the timeout the client will give up on connection.
             If `None`, client will wait forever. Defaults to 100 seconds.
+        :param str ca_cert: path to CA certificate. If left blank, default certificate location \
+            will be used
         """
 
         super(DropboxOAuth2Flow, self).__init__(
@@ -408,7 +417,8 @@ class DropboxOAuth2Flow(DropboxOAuth2FlowBase):
             scope=scope,
             include_granted_scopes=include_granted_scopes,
             use_pkce=use_pkce,
-            timeout=timeout
+            timeout=timeout,
+            ca_certs=ca_certs
         )
         self.redirect_uri = redirect_uri
         self.session = session
